@@ -48,11 +48,11 @@ class FigureResampler(go.Figure):
         Parameters
         ----------
         figure: go.Figure
-            The figure that will be decorated. Can be either an empty figure 
+            The figure that will be decorated. Can be either an empty figure
             (e.g., go.Figure() or make_subplots()) or an existing figure.
         convert_existing_traces: bool
             A bool indicating whether the traces of the passed `figure` should be
-            resampled, by default True. Hence, when set to False, the traces of the 
+            resampled, by default True. Hence, when set to False, the traces of the
             passed `figure` will note be resampled.
         default_n_shown_samples: int, optional
             The default number of samples that will be shown for each trace,
@@ -127,7 +127,7 @@ class FigureResampler(go.Figure):
 
     def check_update_trace_data(
         self,
-        trace: Dict, # TODO
+        trace: dict,
         start=None,
         end=None,
     ) -> Optional[Union[dict, BaseTraceType]]:
@@ -156,9 +156,6 @@ class FigureResampler(go.Figure):
         end : Union[float, str], optional
             The end index for which we want the resampled data to be updated to,
             by default None
-        copy_trace: bool, optional
-            If set to true, the trace object will be copied (no pass by reference)
-            before the trace it's data is updated.
 
         Returns
         -------
@@ -247,6 +244,7 @@ class FigureResampler(go.Figure):
         start: Optional[Union[float, str]] = None,
         stop: Optional[Union[float, str]] = None,
         xaxis_filter: str = None,
+        updated_trace_indices: List[int] = None,
     ) -> List[int]:
         """Check and update the traces within the figure dict.
 
@@ -266,8 +264,10 @@ class FigureResampler(go.Figure):
             The start time for the new resampled data view, by default None.
         stop : Union[float, str], optional
             The end time for the new resampled data view, by default None.
-        xaxis_filter: str, Optional
-            Additional trace-update subplot filter.
+        xaxis_filter: str, optional
+            Additional trace-update subplot filter, by default None.
+        updated_trace_indices: List[int], optional
+            List of trace indices that already have been updated, by default None.
 
         Returns
         -------
@@ -278,10 +278,16 @@ class FigureResampler(go.Figure):
         """
         xaxis_filter_short = None
         if xaxis_filter is not None:
-            xaxis_filter_short = "x" + xaxis_filter.lstrip("xaxis_filter")
+            xaxis_filter_short = "x" + xaxis_filter.lstrip("xaxis")
+
+        if updated_trace_indices is None:
+            updated_trace_indices = []
 
-        updated_trace_indices: List[int] = []
         for idx, trace in enumerate(figure["data"]):
+            # We skip when the trace-idx already has been updated.
+            if idx in updated_trace_indices:
+                continue
+
             if xaxis_filter is not None:
                 # the x-anchor of the trace is stored in the layout data
                 if trace.get("yaxis") is None:
@@ -289,22 +295,47 @@ class FigureResampler(go.Figure):
                     y_axis = "y" + xaxis_filter[1:]
                 else:
                     y_axis = "yaxis" + trace.get("yaxis")[1:]
-                x_anchor_trace = figure["layout"].get(y_axis, {}).get("anchor")
 
-                # we skip when:
+                # Next to the x-anchor, we also fetch the xaxis which matches the
+                # current trace (i.e. if this value is not None, the axis shares the
+                # x-axis with one or more traces).
+                # This is relevant when e.g. fig.update_traces(xaxis='x...') was called.
+                x_anchor_trace = figure["layout"].get(y_axis, {}).get("anchor")
+                if x_anchor_trace is not None:
+                    xaxis_matches = (
+                        figure["layout"]
+                        .get("xaxis" + x_anchor_trace.lstrip("x"), {})
+                        .get("matches")
+                    )
+                else:
+                    xaxis_matches = figure["layout"].get("xaxis", {}).get("matches")
+
+                # print(
+                #     f"x_anchor: {x_anchor_trace} - xaxis_filter: {xaxis_filter} ",
+                #     f"- xaxis_matches: {xaxis_matches}"
+                # )
+
+                # We skip when:
                 # * the change was made on the first row and the trace its anchor is not
-                #   in [None, 'x']
+                #   in [None, 'x'] and the matching (a.k.a. shared) xaxis is not equal
+                #   to the xaxis filter argument.
                 #   -> why None: traces without row/col argument and stand on first row
                 #      and do not have the anchor property (hence the DICT.get() method)
-                # * x-anchor-trace != xaxis_filter-short for NON first rows
+                # * x_axis_filter_short not in [x_anchor or xaxis matches] for
+                #   NON first rows
                 if (
-                    xaxis_filter_short == "x" and x_anchor_trace not in [None, "x"]
+                    xaxis_filter_short == "x"
+                    and (
+                        x_anchor_trace not in [None, "x"]
+                        and xaxis_matches != xaxis_filter_short
+                    )
                 ) or (
-                    xaxis_filter_short != "x" and x_anchor_trace != xaxis_filter_short
+                    xaxis_filter_short != "x"
+                    and (xaxis_filter_short not in [x_anchor_trace, xaxis_matches])
                 ):
                     continue
 
-            # if we managed to find and update the trace, it will return the trace
+            # If we managed to find and update the trace, it will return the trace
             # and thus not None.
             updated_trace = self.check_update_trace_data(trace, start=start, end=stop)
             if updated_trace is not None:
@@ -376,7 +407,7 @@ class FigureResampler(go.Figure):
         Note
         ----
         Constructing traces with **very large data amounts** really takes some time.
-        To speed this up; use this `add_trace()` method -> just create a trace with no 
+        To speed this up; use this `add_trace()` method -> just create a trace with no
         data (empty lists) and pass the high frequency data to this method,
         using the `hf_x` and `hf_y` parameters. See the example below:
         >>> from plotly.subplots import make_subplots
@@ -390,7 +421,7 @@ class FigureResampler(go.Figure):
         -----
         * **Pro tip**: if you do `not want to downsample` your data, set `max_n_samples`
           to the size of your trace!
-        * The `NaN` values in either `hf_y` or `trace.y` will be omitted! We do not 
+        * The `NaN` values in either `hf_y` or `trace.y` will be omitted! We do not
           allow `NaN` values in `hf_x` or `trace.x`.
         * `hf_x`, `hf_y`, and 'hf_hovertext` are useful when you deal with large amounts
           of data (as it can increase the speed of this add_trace() method with ~30%).
@@ -495,7 +526,7 @@ class FigureResampler(go.Figure):
                 hf_hovertext = np.asarray(hf_hovertext)
 
             # Remove NaNs for efficiency (storing less meaningless data)
-            # NaNs introduce gaps between enclosing non-NaN datapoints & might distort
+            # NaNs introduce gaps between enclosing non-NaN data points & might distort
             # the resampling algorithms
             if pd.isna(hf_y).any():
                 not_nan_mask = ~pd.isna(hf_y)
@@ -504,7 +535,7 @@ class FigureResampler(go.Figure):
                 if isinstance(hf_hovertext, np.ndarray):
                     hf_hovertext = hf_hovertext[not_nan_mask]
 
-            # if the categorical or string-like hf_y data is of type object (happens
+            # If the categorical or string-like hf_y data is of type object (happens
             # when y argument is used for the trace constructor instead of hf_y), we
             # transform it to type string as such it will be sent as categorical data
             # to the downsampling algorithm
@@ -568,9 +599,8 @@ class FigureResampler(go.Figure):
                     "hovertext": hf_hovertext,
                 }
 
-
-                # Before we update the trace, we create a new pointer to that trace in 
-                # which the downsampled data will be stored. This way, the original 
+                # Before we update the trace, we create a new pointer to that trace in
+                # which the downsampled data will be stored. This way, the original
                 # data of the trace to this `add_trace` method will not be altered.
                 # We copy (by reference) all the non-data properties of the trace in
                 # the new trace.
@@ -584,8 +614,8 @@ class FigureResampler(go.Figure):
                 }
 
                 # NOTE:
-                # If all the raw data needs to be sent to the javascript, and the trace 
-                # is high-frequency, this would take significant time! 
+                # If all the raw data needs to be sent to the javascript, and the trace
+                # is high-frequency, this would take significant time!
                 # Hence, you first downsample the trace.
                 trace = self.check_update_trace_data(trace)
                 assert trace is not None
@@ -656,7 +686,7 @@ class FigureResampler(go.Figure):
             Figure.
         trace_updater_id
             The id of the `TraceUpdater` component. This component is leveraged by
-            `FigureResampler` to efficiently POST the to-be-updated data to the 
+            `FigureResampler` to efficiently POST the to-be-updated data to the
             front-end.
 
         """
@@ -693,13 +723,12 @@ class FigureResampler(go.Figure):
                         xaxis = t_start_key.split(".")[0]
                         assert xaxis == t_stop_key.split(".")[0]
                         # -> we want to copy the layout on the back-end
-                        updated_trace_indices.extend(
-                            self.check_update_figure_dict(
-                                current_graph,
-                                start=changed_layout[t_start_key],
-                                stop=changed_layout[t_stop_key],
-                                xaxis_filter=xaxis,
-                            )
+                        updated_trace_indices = self.check_update_figure_dict(
+                            current_graph,
+                            start=changed_layout[t_start_key],
+                            stop=changed_layout[t_stop_key],
+                            xaxis_filter=xaxis,
+                            updated_trace_indices=updated_trace_indices,
                         )
 
                 # 2. The user clicked on either autorange | reset axes
@@ -710,10 +739,10 @@ class FigureResampler(go.Figure):
                     for autorange_key in autorange_matches:
                         if changed_layout[autorange_key]:
                             xaxis = autorange_key.split(".")[0]
-                            updated_trace_indices.extend(
-                                self.check_update_figure_dict(
-                                    current_graph, xaxis_filter=xaxis
-                                )
+                            updated_trace_indices = self.check_update_figure_dict(
+                                current_graph,
+                                xaxis_filter=xaxis,
+                                updated_trace_indices=updated_trace_indices,
                             )
                 # 2.1. Autorange -> do nothing, the autorange will be applied on the
                 #      current front-end view
@@ -755,7 +784,13 @@ class FigureResampler(go.Figure):
                 layout_traces_list.append(trace_reduced)
             return layout_traces_list
 
-    def show_dash(self, mode=None, **kwargs):
+    def show_dash(
+        self,
+        mode=None,
+        config: dict | None = None,
+        graph_properties: dict | None = None,
+        **kwargs,
+    ):
         """Registers the `update_graph` callback & show the figure in a dash app.
 
         Parameters
@@ -771,16 +806,32 @@ class FigureResampler(go.Figure):
                 JupyterLab interface. Requires JupyterLab and the `jupyterlab-dash`
                 extension.<br>
             By default None, which will result in the same behavior as ``"external"``.
+        config: dict, optional
+            The configuration options for displaying this figure, by default None.
+            This `config` parameter is the same as the dict that you would pass as
+            `config` argument to the `.show()` method.
+            See more https://plotly.com/python/configuration-options/
+        graph_properties: dict, optional
+            Dictionary of (keyword, value) for the properties that should be passed to
+            the dcc.Graph, by default None.
+            e.g.: {"style": {"width": "50%"}}
+            Note: "config" is not allowed as key in this dict, as there is a distinct
+            `config` parameter for this property in this method.
+            See more https://dash.plotly.com/dash-core-components/graph
         **kwargs: dict
             Additional app.run_server() kwargs.<br>/
             e.g.: port
 
         """
+        graph_properties = {} if graph_properties is None else graph_properties
+        assert "config" not in graph_properties.keys()  # There is a param for config
         # 1. Construct the Dash app layout
         app = JupyterDash("local_app")
         app.layout = dash.html.Div(
             [
-                dash.dcc.Graph(id="resample-figure", figure=self),
+                dash.dcc.Graph(
+                    id="resample-figure", figure=self, config=config, **graph_properties
+                ),
                 TraceUpdater(
                     id="trace-updater", gdID="resample-figure", sequentialUpdate=False
                 ),
